@@ -10,7 +10,6 @@ from di._concurrency import curry_context, gurantee_awaitable
 from di.types.executor import AsyncExecutor, SyncExecutor, Task
 
 ResultType = typing.TypeVar("ResultType")
-T = typing.TypeVar("T")
 
 
 def _all_sync(tasks: typing.List[Task]) -> bool:
@@ -48,14 +47,12 @@ class DefaultExecutor(AsyncExecutor, SyncExecutor):
                         raise exc
                     if inspect.isawaitable(future.result()):
                         raise TypeError(
-                            "Cannot execute async dependencies in a SyncExecutor"
+                            "Cannot execute async dependencies in execute_sync"
                         )
             else:
                 v = task_group[0]()
                 if inspect.isawaitable(v):
-                    raise TypeError(
-                        "Cannot execute async dependencies in a SyncExecutor"
-                    )
+                    raise TypeError("Cannot execute async dependencies in execute_sync")
         return get_result()
 
     async def execute_async(
